.. currentmodule:: sardana.macroserver.msbase

:mod:`~sardana.macroserver.msbase`
=======================================

.. automodule:: sardana.macroserver.msbase

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`MSBaseObject`
    * :class:`MSObject`

MSBaseObject
------------

.. inheritance-diagram:: MSBaseObject
    :parts: 1
    
.. autoclass:: MSBaseObject
    :show-inheritance:

MSObject
------------

.. inheritance-diagram:: MSObject
    :parts: 1
    
.. autoclass:: MSObject
    :show-inheritance:
